@@ -79,19 +79,17 @@ def makeFilePath(path):
             os.mkdir(folder)
     return filepath
 
-import json
+
 def test():
     log = Logger()
     log.d('debug', 1, 'a', {'k':'v'})
     log.i('info', 'some info')
-    log.w('warning', 'some warning', json.dumps({'hello':{'key':'world'}}))
     log.e('error', 123, 3*5)
     try:
         a = 1/0
         log.d(a)
     except:
         log.exc('做除法的时候出错')
-    log.x('critical', -1, json.dumps([1,2,3]))
     pass
 
 
